@@ -1,6 +1,6 @@
 package WWW::AdventCalendar;
 BEGIN {
-  $WWW::AdventCalendar::VERSION = '1.000';
+  $WWW::AdventCalendar::VERSION = '1.001';
 }
 use Moose;
 # ABSTRACT: a calendar for a month of articles (on the web)
@@ -172,15 +172,16 @@ sub build {
     my $output;
 
     print "processing article for $date...\n";
-    $self->output_dir->file("$date.html")->openw->print(
-      $self->_masonize('/article.mhtml', {
-        article => $article->{ $date },
-        date    => $date,
-        next    => ($i < $#dates ? $article->{ $dates[ $i + 1 ] } : undef),
-        prev    => ($i > 0       ? $article->{ $dates[ $i - 1 ] } : undef),
-        year    => $self->year,
-      }),
-    );
+    my $txt = $self->_masonize('/article.mhtml', {
+      article => $article->{ $date },
+      date    => $date,
+      next    => ($i < $#dates ? $article->{ $dates[ $i + 1 ] } : undef),
+      prev    => ($i > 0       ? $article->{ $dates[ $i - 1 ] } : undef),
+      year    => $self->year,
+    });
+
+    my $bytes = Encode::encode('utf-8', $txt);
+    $self->output_dir->file("$date.html")->openw->print($bytes);
   }
 
   for my $date (reverse @dates){
@@ -190,7 +191,7 @@ sub build {
       title     => HTML::Entities::encode_entities($article->title),
       link      => $self->uri . "$date.html",
       id        => $article->atom_id,
-      summary   => Encode::decode('utf-8', $article->body_html),
+      summary   => $article->body_html,
       updated   => $self->_w3cdtf($article->date),
       (map {; category => $_ } @{ $self->categories }),
     );
@@ -214,7 +215,7 @@ sub read_articles {
     my ($name, $path) = fileparse($file);
     $name =~ s{\..+\z}{}; # remove extension
 
-    open my $fh, '<', $file;
+    open my $fh, '<:encoding(utf-8)', $file;
     my $content = do { local $/; <$fh> };
     my $document = Email::Simple->new($content);
     my $isodate  = $name;
@@ -251,7 +252,7 @@ WWW::AdventCalendar - a calendar for a month of articles (on the web)
 
 =head1 VERSION
 
-version 1.000
+version 1.001
 
 =head1 DESCRIPTION
 
